/******************************************************************************
*
* Sample.r -- resources for the Sample application, version 3.0
* 
* Developer Support Center
* Apple Computer, Inc.
* Copyright 1988-1993, Apple Computer, Inc.  All rights reserved.
*
* This file contains all the resource definitions for the Sample application.
* Some of these are common resources, like menus, windows and alerts, and
* others are custom resources.  For the benefit of those without Rez,
* we include 'TMPL' template resources for any custom types.
*
* This file was largely created using resource editors; this source was
* created with Derez and commented.  This is usually a good thing -- it's
* usually easier to create resources using your favorite tools, but it's
* awfully hard to comment things or explain them that way.  Rez source can
* include methodology; resource files have difficulty with that.
*
******************************************************************************/

/******************************************************************************
*
* We use the auto window positioning features of System 7 to keep our windows
* nicely positioned relative to documents.  When using System 6, all windows
* show up in their default positions, which are chosen for 9" monitors.
* So that Rez will compile with the extra auto-centering information at the
* end of window and dialog resources, we #define SystemSevenOrLater.  Note
* that these resource formats still work fine under System 6 -- the system
* doesn't return errors because there's extra information at the end of each
* resource.  It's just that System 6 doesn't move the windows for us.  Smarter
* window positioning is a Sample feature that you only get if you're running
* System 7 or later.
*
******************************************************************************/

#define SystemSevenOrLater	1

/******************************************************************************
*
* Defining qDebug builds names for all our resources.  Not defining this
* variable leaves them out, which saves space in shipping applications.
* Do this in your Makefile, or in the "preprocessor" options for SARez, or
* in the preferences for THINK Rez.
*
******************************************************************************/

/* #define qDebug				1  */

/******************************************************************************
*
* We use lots of system features, so we include lots of system Rez include
* files, plus our own header files.
*
******************************************************************************/

#include "BalloonTypes.r"
#include "Pict.r"
#include "SysTypes.r"
#include "Types.r"

#include "Sample.h"
#include "SampleDialog.h"
#include "SampleUtilities.h"
#include "TrafficLights.h"
#include "Print.h"

/* we use an MBAR resource to conveniently load all the menus */

resource 'MBAR' (rMenuBar, preload) {
	{ mApple, mFile, mEdit, mCircle };	/* four menus */
};


/******************************************************************************
*
* These are the menus we use in Sample.  Four of them (Apple, File, Edit and
* Circle) are in the main menu bar, and the other two (Fonts and Size) are
* waiting for pop-up menus in dialogs to use them.  These aren't very
* exciting.  The only slightly unusual thing about them is the use of the
* constants like "MenuItem2", defined in Sample.h, to set or clear certain
* bits in the menu enabling flags.  We also use our defined "allItems"
* instead of Types.r's defined "allItems" because we can do logical
* operations on it, as shown in the Apple menu declaration.
*
******************************************************************************/

resource 'MENU' (mApple, preload) {
	mApple,
	textMenuProc,
	~MenuItem2,						/* disable dashed line but enable others */
	enabled,
	apple,
	{	"About Sample",
			noIcon, noKey, noMark, plain,
		"-",
			noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (mFile, preload) {
	mFile,
	textMenuProc,
	MenuItem1 | MenuItem2 | MenuItem12,		/* items other than New, Open and */
	enabled,								/* Quit enabled as needed */
	"File",
	{	"New",  
			noIcon, "N", noMark, plain,
		"Open",  
			noIcon, "O", noMark, plain,
		"-",  
			noIcon, noKey, noMark, plain,
		"Close",  
			noIcon, "W", noMark, plain,
		"Save",  
			noIcon, "S", noMark, plain,
		"Save As",  
			noIcon, noKey, noMark, plain,
		"Revert",  
			noIcon, noKey, noMark, plain,
		"-",  
			noIcon, noKey, noMark, plain,
		"Page Setup",  
			noIcon, noKey, noMark, plain,
		"Print",  
			noIcon, "P", noMark, plain,
		"-",  
			noIcon, noKey, noMark, plain,
		"Quit",  
			noIcon, "Q", noMark, plain
	}
};

resource 'MENU' (mEdit, preload) {
	mEdit,
	textMenuProc,
	MenuItem8,		/* Only the Prefs item enabled by default, program does rest */
	enabled,
	"Edit",
	{	"Undo",  
			noIcon, "Z", noMark, plain,
		"-",  
			noIcon, noKey, noMark, plain,
		"Cut",  
			noIcon, "X", noMark, plain,
		"Copy",  
			noIcon, "C", noMark, plain,
		"Paste",  
			noIcon, "V", noMark, plain,
		"Clear",  
			noIcon, noKey, noMark, plain,
		"-",  
			noIcon, noKey, noMark, plain,
		"Edit Preferences",  
			noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (mCircle, preload) {
	mCircle,
	textMenuProc,
	allItems,
	enabled,
	"Circle",
	{	"Add Circle", 
			 noIcon, noKey, noMark, plain,
		"Modify Circle",  
			noIcon, "M", noMark, plain,
		"Delete Circle",  
			noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (mFonts) {
	mFonts,
	textMenuProc,
	allItems,
	enabled,
	"Fonts",
	{	/* array: 0 elements */
	}
};

resource 'MENU' (mSize) {
	mSize,
	textMenuProc,
	allItems,
	enabled,
	"Size",
	{	"9", 
			noIcon, noKey, noMark, plain,
		"10",  
			noIcon, noKey, noMark, plain,
		"12",  
			noIcon, noKey, noMark, plain,
		"14",  
			noIcon, noKey, noMark, plain,
		"18",  
			noIcon, noKey, noMark, plain,
		"24",  
			noIcon, noKey, noMark, plain,
		"36",  
			noIcon, noKey, noMark, plain,
		"48",  
			noIcon, noKey, noMark, plain,
		"72",  
			noIcon, noKey, noMark, plain
	}
};

/******************************************************************************
*
* These are the Alert resources for Sample.  There are lots of them, because
* Sample uses Alert almost exclusively for presenting things that could go
* wrong to the user.  The conditional compilation throughout insures that the
* descriptive resource names don't get built unless the qDebug variable is
* set, keeping them out of the final application.
*
* These alerts all have icon items in them, so we don't have to use the
* different NoteAlert, StopAlert and CautionAlert calls to get the icons we
* want.  The icons are in the system file, not in this file.
*
* Otherwise, these are pretty boring too.  Everything about computers can't
* be exciting.
*
******************************************************************************/

resource 'ALRT' (rSizeTooBigAlert,
#ifdef qDebug
				"Size too big",
#endif
				purgeable) {
	{98, 68, 186, 444},
	rSizeTooBigAlert,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	alertPositionParentWindow
};

resource 'ALRT' (rFeaturesNotPresent,
#ifdef qDebug
				"Features not present",
#endif
				purgeable) {
	{70, 82, 240, 430},
	rFeaturesNotPresent,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rNoMemoryForApp,
#ifdef qDebug
				"Not enough memory",
#endif
				purgeable) {
	{70, 82, 240, 430},
	rNoMemoryForApp,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rNoMemForWindow,
#ifdef qDebug
				"No memory for window",
#endif
				purgeable) {
	{72, 88, 236, 424},
	rNoMemForWindow,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rIOError,
#ifdef qDebug
				"I/O error",
#endif
				purgeable) {
	{86, 84, 208, 428},
	rIOError,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rFileAlreadyOpen,
#ifdef qDebug
				"File already open",
#endif
				purgeable) {
	{90, 86, 202, 426},
	rFileAlreadyOpen,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rNoPermission,
#ifdef qDebug
				"Permission error",
#endif
				purgeable) {
	{90, 86, 202, 426},
	rNoPermission,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rSomeWeirdError,
#ifdef qDebug
				"Weird error",
#endif
				purgeable) {
	{90, 86, 202, 426},
	rSomeWeirdError,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rDiskWriteProt,
#ifdef qDebug
				"Write-protected",
#endif
				purgeable) {
	{90, 86, 202, 426},
	rDiskWriteProt,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rFileVersionInconsistent,
#ifdef qDebug
				"Bad file version",
#endif
				purgeable) {
	{90, 86, 202, 426},
	rFileVersionInconsistent,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rFileDiskLocked,
#ifdef qDebug
				"File or disk locked",
#endif
				purgeable) {
	{129, 62, 233, 450},
	rFileDiskLocked,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rActionAlertBase+kClosing,
#ifdef qDebug
				"Save changes before closing?",
#endif
				purgeable) {
	{88, 79, 205, 433},
	rActionAlertBase+kClosing,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rActionAlertBase+kQuitting,
#ifdef qDebug
				"Save changes before quitting?",
#endif
				purgeable) {
	{88, 79, 205, 433},
	rActionAlertBase+kQuitting,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rCantWriteFile,
#ifdef qDebug
				"Cant write file",
#endif
				purgeable) {
	{129, 62, 233, 450},
	rCantWriteFile,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rReallyRevert,
#ifdef qDebug
				"Sure you want to revert?",
#endif
				purgeable) {
	{129, 62, 233, 450},
	rReallyRevert,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rNoMemoryForOperation, 
#ifdef qDebug
				"No memory for operation", 
#endif
				purgeable) {
	{70, 82, 240, 430},
	rNoMemoryForOperation,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rPrintingError,
#ifdef qDebug
				"A printing error",
#endif
				purgeable) {
	{100, 104, 180, 408},
	rPrintingError,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionMainScreen
};

resource 'ALRT' (rOnlyTenCirclesID,
#ifdef qDebug
				"Only Ten Circles",
#endif
				purgeable) {
	{92, 98, 196, 414},
	rOnlyTenCirclesID,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rLessThan500Please,
#ifdef qDebug
				"Stop at 500, please",
#endif
				purgeable) {
	{67, 96, 247, 416},
	rLessThan500Please,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rInsetTooMuch,
#ifdef qDebug
				"Wrong inset value",
#endif
				purgeable) {
	{104, 80, 216, 432},
	rInsetTooMuch,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rInsetMustBeChanged,
#ifdef qDebug
				"Inset value too big at end of dialog",
#endif
				purgeable) {
	{80, 80, 220, 432},
	rInsetMustBeChanged,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	alertPositionParentWindow
};

resource 'ALRT' (rAboutAlert,
#ifdef qDebug
				"About Sample",
#endif
				purgeable) {
	{78, 122, 226, 390},
	rAboutAlert,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, silent,
		/* [2] */
		OK, visible, silent,
		/* [3] */
		OK, visible, silent,
		/* [4] */
		OK, visible, silent
	},
	centerMainScreen
};

/******************************************************************************
*
* These are the 'DITL' resources for our alerts and dialogs.  They're about
* as interesting as the 'ALRT' resources are.
*
******************************************************************************/

resource 'DITL' (circleDialogID, purgeable) {
	{	/* array DITLarray: 23 elements */
		/* [1] */
		{199, 280, 219, 348},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{199, 200, 219, 264},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{0, 140, 20, 232},
		StaticText {
			disabled,
			"Circle options"
		},
		/* [4] */
		{25, 12, 41, 64},
		StaticText {
			enabled,
			"Font:"
		},
		/* [5] */
		{24, 64, 42, 240},
		UserItem {
			enabled
		},
		/* [6] */
		{52, 14, 68, 54},
		StaticText {
			disabled,
			"Size:"
		},
		/* [7] */
		{52, 67, 68, 107},
		EditText {
			enabled,
			""
		},
		/* [8] */
		{51, 112, 70, 136},
		Picture {
			enabled,
			128
		},
		/* [9] */
		{81, 8, 97, 54},
		StaticText {
			disabled,
			"Style:"
		},
		/* [10] */
		{97, 64, 113, 116},
		CheckBox {
			enabled,
			"Bold"
		},
		/* [11] */
		{113, 64, 129, 123},
		CheckBox {
			enabled,
			"Italic"
		},
		/* [12] */
		{129, 64, 145, 150},
		CheckBox {
			enabled,
			"Underline"
		},
		/* [13] */
		{81, 150, 97, 220},
		CheckBox {
			enabled,
			"Outline"
		},
		/* [14] */
		{97, 150, 113, 225},
		CheckBox {
			enabled,
			"Shadow"
		},
		/* [15] */
		{113, 150, 129, 245},
		CheckBox {
			enabled,
			"Condensed"
		},
		/* [16] */
		{129, 150, 145, 235},
		CheckBox {
			enabled,
			"Extended"
		},
		/* [17] */
		{81, 64, 97, 120},
		CheckBox {
			enabled,
			"Plain"
		},
		/* [18] */
		{155, 13, 172, 54},
		StaticText {
			disabled,
			"Text:"
		},
		/* [19] */
		{156, 67, 172, 237},
		EditText {
			enabled,
			""
		},
		/* [20] */
		{199, 14, 219, 94},
		Button {
			enabled,
			"Color"
		},
		/* [21] */
		{46, 252, 146, 352},
		UserItem {
			disabled
		},
		/* [22] */
		{184, 264, 228, 360},
		UserItem {
			enabled
		},
		/* [23] */
		{0, 0, 0, 0},
		HelpItem {
			disabled,
			HMScanhdlg {
				130
			}
		}
	}
};

resource 'DITL' (prefsID, purgeable) {
	{	/* array DITLarray: 11 elements */
		/* [1] */
		{176, 280, 196, 348},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{176, 200, 196, 264},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{12, 112, 28, 248},
		StaticText {
			disabled,
			"Sample Preferences"
		},
		/* [4] */
		{36, 300, 52, 336},
		EditText {
			enabled,
			""
		},
		/* [5] */
		{36, 8, 60, 292},
		StaticText {
			disabled,
			"Maximum number of circles per document:"
		},
		/* [6] */
		{100, 300, 116, 336},
		EditText {
			enabled,
			""
		},
		/* [7] */
		{88, 8, 120, 292},
		StaticText {
			disabled,
			"Number of pixels each circles rectangle should be, "
			"both tall and wide:"
		},
		/* [8] */
		{132, 300, 148, 336},
		EditText {
			enabled,
			""
		},
		/* [9] */
		{128, 8, 164, 288},
		StaticText {
			disabled,
			"Number of pixels to inset each circle from the boundary rectangle:"
		},
		/* [10] */
		{164, 268, 204, 364},
		UserItem {
			disabled
		},
		/* [11] */
		{68, 95, 84, 265},
		StaticText {
			disabled,
			"For new documents only:"
		}
	}
};

resource 'DITL' (rSizeTooBigAlert, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{60, 296, 80, 364},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{8, 64, 56, 348},
		StaticText {
			disabled,
			"Sample cant accept point sizes larger than ^0 because the "
			"circles are only ^1 pixels tall."
		},
		/* [3] */
		{8, 16, 40, 48},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rFeaturesNotPresent, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{140, 260, 160, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 124, 316},
		StaticText {
			disabled,
			"One of the Macintosh system features that Sample requires is "
			"not present, and the program cannot continue.\n\nPlease check "
			"the documentation to insure your Macintosh meets the requirements "
			"to run Sample."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			2
		}
	}
};

resource 'DITL' (rNoMemoryForApp, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{140, 260, 160, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 124, 316},
		StaticText {
			disabled,
			"Samples memory partition is too small for it to run effectively."
			"\n\nUse Get Info in the Finder after selecting the "
			"Sample application to allocate more memory for Sample."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			2
		}
	}
};

resource 'DITL' (rNoMemForWindow, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{136, 256, 156, 324},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 112, 316},
		StaticText {
			disabled,
			"There is not enough memory to open another window.\n\nTry "
			"closing some document windows in Sample to free up memory."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rIOError, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{94, 264, 114, 332},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 89, 321},
		StaticText {
			disabled,
			"There was a disk error trying to use the document ^0.  Try "
			"using a different disk."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rFileAlreadyOpen, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 260, 104, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 76, 312},
		StaticText {
			disabled,
			"The document ^1 is already opened by another program."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rNoPermission, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 260, 104, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 76, 312},
		StaticText {
			disabled,
			"You dont have permission to use or create the file ^1."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rSomeWeirdError, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 260, 104, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 76, 312},
		StaticText {
			disabled,
			"There was an error (^0) while working with ^1."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rDiskWriteProt, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 260, 104, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 76, 312},
		StaticText {
			disabled,
			"The disk for the document ^1 is write-protected."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rFileVersionInconsistent, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 260, 104, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 76, 312},
		StaticText {
			disabled,
			"The document ^1 was created with a later version of Sample. "
			"This version cant read this document."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rFileDiskLocked, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{72, 296, 92, 376},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{12, 22, 44, 54},
		Icon {
			disabled,
			1
		},
		/* [3] */
		{12, 76, 60, 376},
		StaticText {
			disabled,
			"This document or its disk is locked. You can open the document, "
			"but you wont be able to modify it."
		}
	}
};

resource 'DITL' (rActionAlertBase+kClosing) {
	{	/* array DITLarray: 5 elements */
		/* [1] */
		{87, 284, 107, 344},
		Button {
			enabled,
			"Save"
		},
		/* [2] */
		{87, 211, 107, 271},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{87, 70, 107, 155},
		Button {
			enabled,
			"Dont Save"
		},
		/* [4] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			2
		},
		/* [5] */
		{10, 72, 76, 344},
		StaticText {
			disabled,
			"Save changes to the ^0 document ^1 before closing?"
		}
	}
};

resource 'DITL' (rActionAlertBase+kQuitting) {
	{	/* array DITLarray: 5 elements */
		/* [1] */
		{87, 284, 107, 344},
		Button {
			enabled,
			"Save"
		},
		/* [2] */
		{87, 211, 107, 271},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{87, 70, 107, 155},
		Button {
			enabled,
			"Dont Save"
		},
		/* [4] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			2
		},
		/* [5] */
		{10, 72, 76, 344},
		StaticText {
			disabled,
			"Save changes to the ^0 document ^1 before quitting?"
		}
	}
};

resource 'DITL' (rCantWriteFile, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{72, 296, 92, 376},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{12, 22, 44, 54},
		Icon {
			disabled,
			1
		},
		/* [3] */
		{12, 76, 60, 376},
		StaticText {
			disabled,
			"This document or its disk is locked.\nUse Save as to save the "
			"document to a new file."
		}
	}
};

resource 'DITL' (rReallyRevert, purgeable) {
	{	/* array DITLarray: 4 elements */
		/* [1] */
		{76, 308, 96, 376},
		Button {
			enabled,
			"Revert"
		},
		/* [2] */
		{12, 22, 44, 54},
		Icon {
			disabled,
			2
		},
		/* [3] */
		{12, 76, 60, 376},
		StaticText {
			disabled,
			"Revert to the last saved version of ^0, discarding all changes?"
		},
		/* [4] */
		{76, 228, 96, 292},
		Button {
			enabled,
			"Cancel"
		}
	}
};

resource 'DITL' (rNoMemoryForOperation, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{140, 260, 160, 328},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 124, 316},
		StaticText {
			disabled,
			"Theres not enough memory for Sample to complete this operation.\n\n"
			"Please try closing some windows or increasing Samples partition size "
			"with Get Info... in the Finder."
		},
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			2
		}
	}
};

resource 'DITL' (rPrintingError, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{52, 224, 72, 292},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 44, 288},
		StaticText {
			disabled,
			"Printing error ^0 occurred."
		},
		/* [3] */
		{12, 20, 44, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rOnlyTenCirclesID, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{76, 236, 96, 304},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 64, 288},
		StaticText {
			disabled,
			"The maximum number of circles in the document must be between "
			"1 and 10."
		},
		/* [3] */
		{12, 20, 44, 52},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rLessThan500Please, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{152, 240, 172, 308},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{8, 64, 144, 292},
		StaticText {
			disabled,
			"One of the things Sample doesnt teach is how to deal with "
			"QuickDraw boundary conditions if you let people size rectangles "
			"up to 65,536 pixels tall.\n\nSo it doesnt let you enter a "
			"size larger than 500 pixels.   Sorry."
		},
		/* [3] */
		{9, 14, 41, 46},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rInsetTooMuch, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{84, 272, 104, 340},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 72, 316},
		StaticText {
			disabled,
			"For the size of the rectangles youve specified, the inset "
			"value must be between 0 and ^0."
		},
		/* [3] */
		{11, 13, 43, 45},
		Icon {
			disabled,
			2
		}
	}
};

resource 'DITL' (rInsetMustBeChanged, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{112, 272, 132, 340},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{10, 60, 96, 316},
		StaticText {
			disabled,
			"An inset value of ^0 is too large for the rectangles youve "
			"specified.  The inset will be the maximum value of ^1."
		},
		/* [3] */
		{12, 15, 44, 47},
		Icon {
			disabled,
			1
		}
	}
};

resource 'DITL' (rAboutAlert, purgeable) {
	{	/* array DITLarray: 5 elements */
		/* [1] */
		{116, 180, 136, 260},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{8, 8, 24, 214},
		StaticText {
			disabled,
			"Sample 3.0 (Traffic Light Plus)"
		},
		/* [3] */
		{32, 8, 84, 244},
		StaticText {
			disabled,
			"Copyright  1989-1993,\n    Apple Computer, Inc.\n    "
			"All rights reserved."
		},
		/* [4] */
		{88, 8, 104, 136},
		StaticText {
			disabled,
			"Brought to you by:"
		},
		/* [5] */
		{108, 24, 140, 167},
		StaticText {
			disabled,
			"Developer Technical Support (DSC)"
		}
	}
};

/******************************************************************************
*
* These string resources contain things like the file name for our preferences
* file and the name of our application so the Finder can say what application
* should be used to open our documents.
*
******************************************************************************/

resource 'STR ' (rPrefsFileName
#ifdef qDebug
				, "Prefs file name"
#endif
				){
#ifdef PascalVersion
		"Sample.p Preferences"
#endif
#ifdef CVersion
		"Sample.c Preferences"
#endif
};

resource 'STR ' (kMissingAppNameStr
#ifdef qDebug
				, "Program name"
#endif
				){
#ifdef PascalVersion
	"Pascal Sample"
#endif
#ifdef CVersion
	"C Sample"
#endif
};

/******************************************************************************
*
* This is a ResEdit template for the "DfSz" resource, which contains a two-byte
* integer with a size for a circle.  This appears as a "data" statement because 
* there's no Rez template for ResEdit templates.
*
******************************************************************************/

data 'TMPL' (129, "DfSz", purgeable) {
	$"1144 6566 6175 6C74 2046 6F6E 7420 5369 7A65 4457 5244"                     /* .Default Font SizeDWRD */
};

/******************************************************************************
*
* This picture is the icon drawn next to the type-in pop-up menu for text
* size in the "Modify Circle" dialog.
*
******************************************************************************/

resource 'PICT' (128
#ifdef qDebug
				, "Pop-down arrow PICT"
#endif
				) {
	{392, 767, 411, 791},
	VersionOne {
		{	/* array OpCodes: 2 elements */
			/* [1] */
			ClipRgn {
				{392, 767, 424, 799},
				$""
			},
			/* [2] */
			BitsRect {
				4,
				{392, 767, 424, 799},
				{392, 767, 424, 799},
				{392, 767, 424, 799},
				srcCopy,
				$"FFFF FE00 8000 0200 8000 0300 8000 0300 8000 0300 8000 0300"
				$"83FF 8300 81FF 0300 80FE 0300 807C 0300 8038 0300 8010 0300"
				$"8000 0300 8000 0300 8000 0300 8000 0300 8000 0300 FFFF FF00"
				$"3FFF FF00 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
				$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
				$"0000 0000 0000 0000"
			}
		}
	}
};

/******************************************************************************
*
* The following dialog color table isn't really used -- but if it's not
* present, even though it's empty, the Modify Circle dialog won't have a
* CGrafPort, meaning it can't show any but the classic eight QuickDraw colors.
* This resource makes sure the dialog's port is a CGrafPort.
*
******************************************************************************/

resource 'dctb' (circleDialogID, "Required for CGrafPort in dialog") {
	{	/* array ColorSpec: 0 elements */
	}
};

/******************************************************************************
*
* These large collections of hex numbers are the icon families for Sample's
* application, documents, preferences file and stationery.  I heartily
* recommend using a resource editor to manipulate BNDL, FREF and icon family
* resources, so these pass pretty much without comment (not even symbolic
* constants, since they're not referenced from the program itself).
*
******************************************************************************/

resource 'icl8' (128) {
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"
	$"0000 0000 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5FF FF00 0000 0000 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 2BFF 0000 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD FDF5 F5F5 F5FF 2B2B"
	$"FF00 0000 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 FDD8 D8D8"
	$"D8FD F5F5 F5FF 2B2B 2BFF 0000 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD D8D8 D8D8 D8D8 FDF5 F5FF 2B2B 2B2B FF00 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5FD D8D8 D8D8 D8D8 FDF5 F5FF FFFF"
	$"FFFF FFFF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5FD D8D8 D8D8"
	$"D8D8 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD D8D8 D8D8 D8D8 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 FDD8 D8D8 D8FD F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD"
	$"FDF5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD FDF5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 FD05 0505"
	$"05FD F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD 0505 0505 0505 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5FD 0505 0505 0505 FDF5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5FD 0505 0505"
	$"0505 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD 0505 0505 0505 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 FD05 0505 05FD F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD"
	$"FDF5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD FDF5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 FDE3 E3E3"
	$"E3FD F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD E3E3 E3E3 E3E3 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5FD E3E3 E3E3 E3E3 FDF5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5FD E3E3 E3E3"
	$"E3E3 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FD E3E3 E3E3 E3E3 FDF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 FDE3 E3E3 E3FD F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5FD FDFD"
	$"FDF5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'icl8' (129, purgeable) {
	$"0000 0000 0000 0000 0000 0000 0000 00FF 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 FFF5"
	$"FF00 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 00FF F5F5 F5FF 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 FFF5 F5F5 F5F5 FF00 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 00FF F5F5 FFFF"
	$"FFF5 F5FF 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 FFF5 F5FF D8D8 D8FF F5F5 FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 00FF F5F5 FFD8 D8D8 D8D8 FFF5 F5FF 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 FFF5 F5F5 FFD8 D8D8"
	$"D8D8 FFF5 F5F5 FF00 0000 0000 0000 0000 0000 0000 0000 00FF"
	$"F5F5 F5F5 FFD8 D8D8 D8D8 FFF5 F5F5 F5FF 0000 0000 0000 0000"
	$"0000 0000 0000 FFF5 F5F5 F5F5 F5FF D8D8 D8FF F5F5 F5F5 F5F5"
	$"FF00 0000 0000 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 FFFF"
	$"FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 0000 0000 FFF5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FFF5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5FF 0505"
	$"05FF F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 00FF F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF05 0505 0505 FFFF FFFF FFFF F5F5 F5F5 F5FF 0000"
	$"FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 FF05 0505 05FF 0808 0808 0808"
	$"FFF5 F5F5 F5F5 FF00 00FF F5F5 F5F5 F5F5 F5F5 F5F5 FF05 0505"
	$"FF08 0808 0808 0808 08FF F5F5 F5F5 F5FF 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5FF 05FF 0808 FFFF 0808 0808 0808 FFF5 F5F5 FF00"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 FF08 08FF F5F5 FF08 0808"
	$"0808 08FF F5FF 0000 0000 0000 FFF5 F5F5 F5F5 F5F5 FFFF FF08"
	$"08FF FFFF FFFF FFFF FF08 0808 FFFF FFFF 0000 0000 00FF F5F5"
	$"F5F5 F5F5 F5F5 FF08 0808 FFFF 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 FFF5 F5F5 F5F5 F5FF E3FF 0808 0808 0808 0808"
	$"0808 0808 08FF FFFF 0000 0000 0000 00FF F5F5 F5F5 FFE3 E3E3"
	$"FF08 0808 0808 0808 0808 0808 08FF FFFF 0000 0000 0000 0000"
	$"FFF5 F5F5 FFE3 E3E3 E3FF 0808 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 0000 00FF F5F5 FFE3 E3E3 E3E3 FFFF FFFF FFFF"
	$"FFFF FF08 08FF FFFF 0000 0000 0000 0000 0000 FFF5 F5FF E3E3"
	$"E3FF F5F5 F5F5 FF00 0000 00FF FFFF FFFF 0000 0000 0000 0000"
	$"0000 00FF F5F5 FFFF FFF5 F5F5 F5FF 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 0000 0000 FFF5 F5F5 F5F5 F5F5 FF00 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 00FF F5F5"
	$"F5F5 F5FF 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 FFF5 F5F5 FF00 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF F5FF 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"FF"
};

resource 'icl8' (130) {
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"
	$"0000 0000 0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5FF FF00 0000 0000 0000 0000 0000 00FF F5F5 FFFF"
	$"FFFF FFFF FFFF FFFF F5F5 F5F5 F5FF 2BFF 0000 0000 0000 0000"
	$"0000 00FF F5F5 FFF5 F5F5 F5F5 F5F5 F5FF FFF5 F5F5 F5FF 2B2B"
	$"FF00 0000 0000 0000 0000 00FF F5F5 FFF5 F5F5 F5D8 D8F5 00FF"
	$"2BFF F5F5 F5FF 2B2B 2BFF 0000 0000 0000 0000 00FF F5F5 FFF5"
	$"F5F5 D8D8 D8D8 F5FF FFFF FFF5 F5FF 2B2B 2B2B FF00 0000 0000"
	$"0000 00FF F5F5 FFF5 F5F5 D8D8 D8D8 F5F5 F5F5 FFF5 F5FF FFFF"
	$"FFFF FFFF 0000 0000 0000 00FF F5F5 FFF5 F5F5 F5D8 D8F5 F5F5"
	$"F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5"
	$"F5F5 F5FB FBF5 F5F5 F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FFF5 F5F5 FB05 05FB F5F5 F5F5 FFF5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5 F5F5 FB05 05FB F5F5"
	$"F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5"
	$"F5F5 F5FB FBF5 F5F5 F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FFF5 F5F5 F5E3 E3F5 F5F5 F5F5 FFF5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5 F5F5 E3E3 E3E3 F5F5"
	$"F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5"
	$"F5F5 E3E3 E3E3 F5F5 F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FFF5 F5F5 F5E3 E3F5 F5F5 F5F5 FFF5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 FFF5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFF5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF 00F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5FF FFF5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FF00"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5FF 00FF FF00 FFF5 FFFF FFFF FFFF F5FF FFFF FFFF"
	$"FFF5 F5FF 0000 0000 0000 00FF F5FF 00FF FF00 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FF00"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5F5 F5FF FFF5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FF00"
	$"00FF F5F5 FFFF FFFF FFFF FFF5 FFFF FFFF F5F5 F5FF 0000 0000"
	$"0000 00FF F5FF 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF F5FF 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000 00FF F5F5 FF00"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'icl8' (131, "Stationery", purgeable) {
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FF00 0000 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 FDFD FDFD F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5FD D8D8 D8D8 FDF5 F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FDD8 D8D8 D8D8"
	$"D8FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 FDD8 D8D8 D8D8 D8FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 FDD8 D8D8 D8D8 D8FD F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FDD8 D8D8 D8D8"
	$"D8FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5FD D8D8 D8D8 FDF5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 FDFD FDFD F5F5 F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 FDFD FDFD F5F5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5FD 0505 0505 FDF5 F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FD05 0505 0505"
	$"05FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 FD05 0505 0505 05FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 FD05 0505 0505 05FD F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FD05 0505 0505"
	$"05FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5FD 0505 0505 FDF5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 FDFD FDFD F5F5 F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 FDFD FDFD F5F5 F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5FD E3E3 E3E3 FDF5 F5F5 F5F5 F5F5"
	$"F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FDE3 E3E3 E3E3"
	$"E3FD F5F5 F5F5 F5F5 F5F5 FFF9 FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 FDE3 E3E3 E3E3 E3FD F5F5 FFFF FFFF FFFF FFF9 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 FDE3 E3E3 E3E3 E3FD F5F5 FF2B 2B2B"
	$"F7FF F9F7 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 FDE3 E3E3 E3E3"
	$"E3FD F5F5 FF2B 2BF7 FFF9 F72B FF00 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5FD E3E3 E3E3 FDF5 F5F5 FF2B F7FF F9F7 2BF6 FF00 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 FDFD FDFD F5F5 F5F5 FFF7 FFF9"
	$"F72B F6F6 FF00 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF F9F7 2BF6 F6F6 FF00 0000 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF9 F72B F6F6 F6F6 FF00 0000"
	$"0000 0000 FFF9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F7 2BF6"
	$"F6F6 F6F6 FF00 0000 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF"
};

resource 'ICN#' (128) {
	{	/* array: 2 elements */
		/* [1] */
		$"1FFF FC00 1000 0600 1000 0500 1007 8480 100F C440 101F E420"
		$"101F E7F0 101F E010 101F E010 100F C010 1007 8010 1000 0010"
		$"1007 8010 100F C010 101F E010 101F E010 101F E010 101F E010"
		$"100F C010 1007 8010 1000 0010 1007 8010 100F C010 101F E010"
		$"101F E010 101F E010 101F E010 100F C010 1007 8010 1000 0010"
		$"1000 0010 1FFF FFF0",
		/* [2] */
		$"1FFF FC00 1FFF FE00 1FFF FF00 1FFF FF80 1FFF FFC0 1FFF FFE0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0"
	}
};

resource 'ICN#' (129) {
	{	/* array: 2 elements */
		/* [1] */
		$"0001 0000 0002 8000 0004 4000 0008 2000 0013 9000 0024 4800"
		$"0048 2400 0088 2200 0108 2100 0204 4080 0403 8040 0800 0020"
		$"1003 8010 2004 4008 4008 3F04 8008 4082 4008 8041 2005 3022"
		$"1002 4814 080E 7F8F 0402 3007 0207 0007 0108 8007 0088 4007"
		$"0048 7FE7 0024 421F 0013 8407 0008 0800 0004 1000 0002 2000"
		$"0001 4000 0000 80",
		/* [2] */
		$"0001 0000 0003 8000 0007 C000 000F E000 001F F000 003F F800"
		$"007F FC00 00FF FE00 01FF FF00 03FF FF80 07FF FFC0 0FFF FFE0"
		$"1FFF FFF0 3FFF FFF8 7FFF FFFC FFFF FFFE 7FFF FFFF 3FFF FFFE"
		$"1FFF FFFC 0FFF FFFF 07FF FFFF 03FF FFFF 01FF FFFF 00FF FFFF"
		$"007F FFFF 003F FE1F 001F FC07 000F F800 0007 F000 0003 E000"
		$"0001 C000 0000 80"
	}
};

resource 'ICN#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"1FFF FC00 1000 0600 13FF 0500 1201 8480 1219 4440 123D E420"
		$"123C 27F0 1218 2010 1218 2010 123C 2010 123C 2010 1218 2010"
		$"1218 2010 123C 2010 123C 2010 1218 2010 1200 2010 13FF E010"
		$"1000 0010 1180 0010 1240 0010 15AF DF90 15A0 0010 1240 0010"
		$"1180 0010 1180 0010 124F EF10 1420 0010 1420 0010 1240 0010"
		$"1180 0010 1FFF FFF0",
		/* [2] */
		$"1FFF FC00 1FFF FE00 1FFF FF00 1FFF FF80 1FFF FFC0 1FFF FFE0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0"
	}
};

resource 'ICN#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"3FFF FFE0 2000 0020 200F 0038 201F 8028 203F C028 203F C028"
		$"203F C028 203F C028 201F 8028 200F 0028 2000 0028 200F 0028"
		$"201F 8028 203F C028 203F C028 203F C028 203F C028 201F 8028"
		$"200F 0028 2000 0028 200F 0028 201F 8028 203F C028 203F CFE8"
		$"203F C848 203F C888 201F 8908 200F 0A08 2000 0C08 3FFF F808"
		$"0800 0008 0FFF FFF8",
		/* [2] */
		$"3FFF FFE0 3FFF FFE0 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8"
		$"3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8"
		$"3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8"
		$"3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8"
		$"3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8 3FFF FFF8"
		$"0FFF FFF8 0FFF FFF8"
	}
};

resource 'icl4' (129) {
	$"0000 0000 0000 000F 0000 0000 0000 0000 0000 0000 0000 00FC"
	$"F000 0000 0000 0000 0000 0000 0000 0FC0 CF00 0000 0000 0000"
	$"0000 0000 0000 FC0C 0CF0 0000 0000 0000 0000 0000 000F C0FF"
	$"F0CF 0000 0000 0000 0000 0000 00FC 0F33 3F0C F000 0000 0000"
	$"0000 0000 0FC0 F333 33F0 CF00 0000 0000 0000 0000 FC0C F333"
	$"33FC 0CF0 0000 0000 0000 000F C0C0 F333 33F0 C0CF 0000 0000"
	$"0000 00FC 0C0C 0F33 3F0C 0C0C F000 0000 0000 0FC0 C0C0 C0FF"
	$"F0C0 C0C0 CF00 0000 0000 FC0C 0C0C 0C0C 0C0C 0C0C 0CF0 0000"
	$"000F C0C0 C0C0 C0FF F0C0 C0C0 C0CF 0000 00FC 0C0C 0C0C 0F11"
	$"1F0C 0C0C 0C0C F000 0FC0 C0C0 C0C0 F111 11FF FFFF C0C0 CF00"
	$"FC0C 0C0C 0C0C F111 1FCC CCCC FC0C 0CF0 0FC0 C0C0 C0C0 F111"
	$"FCCC CCCC CFC0 C0CF 00FC 0C0C 0C0C 0F1F CCFF CCCC CCFC 0CF0"
	$"000F C0C0 C0C0 C0FC CF00 FCCC CCCF CF00 0000 FC0C 0C0C FFFC"
	$"CFFF FFFF FCCC FFFF 0000 0FC0 C0C0 C0FC CCFF CCCC CCCC CFFF"
	$"0000 00FC 0C0C 0F8F CCCC CCCC CCCC CFFF 0000 000F C0C0 F888"
	$"FCCC CCCC CCCC CFFF 0000 0000 FC0C F888 8FCC CCCC CCCC CFFF"
	$"0000 0000 0FC0 F888 88FF FFFF FFFC CFFF 0000 0000 00FC 0F88"
	$"8F0C 0CF0 000F FFFF 0000 0000 000F C0FF F0C0 CF00 0000 0FFF"
	$"0000 0000 0000 FC0C 0C0C F000 0000 0000 0000 0000 0000 0FC0"
	$"C0CF 0000 0000 0000 0000 0000 0000 00FC 0CF0 0000 0000 0000"
	$"0000 0000 0000 000F CF00 0000 0000 0000 0000 0000 0000 0000"
	$"F0"
};

resource 'icl4' (128) {
	$"000F FFFF FFFF FFFF FFFF FF00 0000 0000 000F 0C0C 0C0C 0C0C"
	$"0C0C 0FF0 0000 0000 000F C0C0 C0C0 C0C0 C0C0 CFCF 0000 0000"
	$"000F 0C0C 0C0C 0AAA AC0C 0FCC F000 0000 000F C0C0 C0C0 A333"
	$"3AC0 CFCC CF00 0000 000F 0C0C 0C0A 3333 33AC 0FCC CCF0 0000"
	$"000F C0C0 C0CA 3333 33A0 CFFF FFFF 0000 000F 0C0C 0C0A 3333"
	$"33AC 0C0C 0C0F 0000 000F C0C0 C0CA 3333 33A0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C A333 3A0C 0C0C 0C0F 0000 000F C0C0 C0C0 CAAA"
	$"A0C0 C0C0 C0CF 0000 000F 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 CAAA A0C0 C0C0 C0CF 0000 000F 0C0C 0C0C A111"
	$"1A0C 0C0C 0C0F 0000 000F C0C0 C0CA 1111 11A0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0A 1111 11AC 0C0C 0C0F 0000 000F C0C0 C0CA 1111"
	$"11A0 C0C0 C0CF 0000 000F 0C0C 0C0A 1111 11AC 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 A111 1AC0 C0C0 C0CF 0000 000F 0C0C 0C0C 0AAA"
	$"AC0C 0C0C 0C0F 0000 000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C 0AAA AC0C 0C0C 0C0F 0000 000F C0C0 C0C0 A888"
	$"8AC0 C0C0 C0CF 0000 000F 0C0C 0C0A 8888 88AC 0C0C 0C0F 0000"
	$"000F C0C0 C0CA 8888 88A0 C0C0 C0CF 0000 000F 0C0C 0C0A 8888"
	$"88AC 0C0C 0C0F 0000 000F C0C0 C0CA 8888 88A0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C A888 8A0C 0C0C 0C0F 0000 000F C0C0 C0C0 CAAA"
	$"A0C0 C0C0 C0CF 0000 000F 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000 000F FFFF FFFF FFFF"
	$"FFFF FFFF FFFF"
};

resource 'icl4' (130) {
	$"000F FFFF FFFF FFFF FFFF FF00 0000 0000 000F 0C0C 0C0C 0C0C"
	$"0C0C 0FF0 0000 0000 000F C0FF FFFF FFFF C0C0 CFCF 0000 0000"
	$"000F 0CFC 0C0C 0C0F FC0C 0FCC F000 0000 000F C0F0 C0C3 30CF"
	$"CFC0 CFCC CF00 0000 000F 0CFC 0C33 330F FFFC 0FCC CCF0 0000"
	$"000F C0F0 C033 33C0 C0F0 CFFF FFFF 0000 000F 0CFC 0C03 3C0C"
	$"0CFC 0C0C 0C0F 0000 000F C0F0 C0CE E0C0 C0F0 C0C0 C0CF 0000"
	$"000F 0CFC 0CE1 1E0C 0CFC 0C0C 0C0F 0000 000F C0F0 C0E1 1EC0"
	$"C0F0 C0C0 C0CF 0000 000F 0CFC 0C0E EC0C 0CFC 0C0C 0C0F 0000"
	$"000F C0F0 C0C8 80C0 C0F0 C0C0 C0CF 0000 000F 0CFC 0C88 880C"
	$"0CFC 0C0C 0C0F 0000 000F C0F0 C088 88C0 C0F0 C0C0 C0CF 0000"
	$"000F 0CFC 0C08 8C0C 0CFC 0C0C 0C0F 0000 000F C0F0 C0C0 C0C0"
	$"C0F0 C0C0 C0CF 0000 000F 0CFF FFFF FFFF FFFC 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000 000F 0C0F FC0C 0C0C"
	$"0C0C 0C0C 0C0F 0000 000F C0F0 0FC0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0F0F F0FC FFFF FF0F FFFF FC0F 0000 000F CF0F F0F0 C0C0"
	$"C0C0 C0C0 C0CF 0000 000F 0CF0 0F0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF F0C0 C0C0 C0C0 C0C0 C0CF 0000 000F 0C0F FC0C 0C0C"
	$"0C0C 0C0C 0C0F 0000 000F C0F0 0FC0 FFFF FFF0 FFFF C0CF 0000"
	$"000F 0F00 00FC 0C0C 0C0C 0C0C 0C0F 0000 000F CF00 00F0 C0C0"
	$"C0C0 C0C0 C0CF 0000 000F 0CF0 0F0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF F0C0 C0C0 C0C0 C0C0 C0CF 0000 000F FFFF FFFF FFFF"
	$"FFFF FFFF FFFF"
};

resource 'icl4' (131) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFF0 0000 00FC 0C0C 0C0C 0C0C"
	$"0C0C 0C0C 0CF0 0000 00F0 C0C0 C0C0 AAAA C0C0 C0C0 C0FF F000"
	$"00FC 0C0C 0C0A 3333 AC0C 0C0C 0CFD F000 00F0 C0C0 C0A3 3333"
	$"3AC0 C0C0 C0FD F000 00FC 0C0C 0CA3 3333 3A0C 0C0C 0CFD F000"
	$"00F0 C0C0 C0A3 3333 3AC0 C0C0 C0FD F000 00FC 0C0C 0CA3 3333"
	$"3A0C 0C0C 0CFD F000 00F0 C0C0 C0CA 3333 A0C0 C0C0 C0FD F000"
	$"00FC 0C0C 0C0C AAAA 0C0C 0C0C 0CFD F000 00F0 C0C0 C0C0 C0C0"
	$"C0C0 C0C0 C0FD F000 00FC 0C0C 0C0C AAAA 0C0C 0C0C 0CFD F000"
	$"00F0 C0C0 C0CA 1111 A0C0 C0C0 C0FD F000 00FC 0C0C 0CA1 1111"
	$"1A0C 0C0C 0CFD F000 00F0 C0C0 C0A1 1111 1AC0 C0C0 C0FD F000"
	$"00FC 0C0C 0CA1 1111 1A0C 0C0C 0CFD F000 00F0 C0C0 C0A1 1111"
	$"1AC0 C0C0 C0FD F000 00FC 0C0C 0C0A 1111 AC0C 0C0C 0CFD F000"
	$"00F0 C0C0 C0C0 AAAA C0C0 C0C0 C0FD F000 00FC 0C0C 0C0C 0C0C"
	$"0C0C 0C0C 0CFD F000 00F0 C0C0 C0C0 AAAA C0C0 C0C0 C0FD F000"
	$"00FC 0C0C 0C0A 8888 AC0C 0C0C 0CFD F000 00F0 C0C0 C0A8 8888"
	$"8AC0 C0C0 C0FD F000 00FC 0C0C 0CA8 8888 8A0C FFFF FFFD F000"
	$"00F0 C0C0 C0A8 8888 8AC0 FCCC CFDC F000 00FC 0C0C 0CA8 8888"
	$"8A0C FCCC FDCC F000 00F0 C0C0 C0CA 8888 A0C0 FCCF DCCC F000"
	$"00FC 0C0C 0C0C AAAA 0C0C FCFD CCCC F000 00F0 C0C0 C0C0 C0C0"
	$"C0C0 FFDC CCCC F000 00FF FFFF FFFF FFFF FFFF FDCC CCCC F000"
	$"0000 FDDD DDDD DDDD DDDD DCCC CCCC F000 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF F0"
};

resource 'ics8' (129) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 00FF"
	$"0000 0000 0000 0000 0000 0000 0000 FFF5 FF00 0000 0000 0000"
	$"0000 0000 00FF F5D8 F5FF 0000 0000 0000 0000 0000 FFF5 D8D8"
	$"D8F5 FF00 0000 0000 0000 00FF F5F5 F5D8 F5F5 F5FF 0000 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 FF00 0000 00FF F5F5 F5F5 F505"
	$"F5FF FFF5 F5FF 0000 FFF5 F5F5 F5F5 0505 FF08 08FF F5F5 FF00"
	$"00FF F5F5 F5F5 F5FF 08FF 0808 FFFF FF00 0000 FFF5 F5FF FF08"
	$"FFFF FFFF 08FF FF00 0000 00FF F5F5 F5FF 0808 0808 08FF FF00"
	$"0000 0000 FFF5 E3E3 FFFF FFFF FFFF FF00 0000 0000 00FF F5E3"
	$"F5FF 0000 00FF FF00 0000 0000 0000 FFF5 FF00 0000 0000 0000"
	$"0000 0000 0000 00FF"
};

resource 'ics8' (128) {
	$"00FF FFFF FFFF FFFF FFFF FF00 0000 0000 00FF F5F5 F5F5 F5F5"
	$"F5F5 FFFF 0000 0000 00FF F5F5 F5F5 D8D8 F500 FF2B FF00 0000"
	$"00FF F5F5 F5D8 D8D8 D8F5 FFFF FFFF 0000 00FF F5F5 F5D8 D8D8"
	$"D8F5 F5F5 F5FF 0000 00FF F5F5 F5F5 D8D8 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5F5 FBFB F5F5 F5F5 F5FF 0000 00FF F5F5 F5FB 0505"
	$"FBF5 F5F5 F5FF 0000 00FF F5F5 F5FB 0505 FBF5 F5F5 F5FF 0000"
	$"00FF F5F5 F5F5 FBFB F5F5 F5F5 F5FF 0000 00FF F5F5 F5F5 E3E3"
	$"F5F5 F5F5 F5FF 0000 00FF F5F5 F5E3 E3E3 E3F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5E3 E3E3 E3F5 F5F5 F5FF 0000 00FF F5F5 F5F5 E3E3"
	$"F5F5 F5F5 F5FF 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics8' (130) {
	$"00FF FFFF FFFF FFFF FFFF FFFF 0000 0000 00FF F5FF FFFF FFFF"
	$"F5F5 FFFF FF00 0000 00FF F5FF F5F5 F5F5 FFF5 FF2B FFFF 0000"
	$"00FF F5FF F5D8 D8F5 F5FF FFFF FFFF 0000 00FF F5FF F5F5 F5F5"
	$"F5FF F5F5 F5FF 0000 00FF F5FF F505 05F5 F5FF F5F5 F5FF 0000"
	$"00FF F5FF F5F5 F5F5 F5FF F5F5 F5FF 0000 00FF F5FF F5E3 E3F5"
	$"F5FF F5F5 F5FF 0000 00FF F5FF FFFF FFFF FFFF F5F5 F5FF 0000"
	$"00FF F5F5 FFFF F5F5 F5F5 F5F5 F5FF 0000 00FF F5FF 0000 FFF5"
	$"F5F5 F5F5 00FF 0000 00FF FF00 FFFF 00FF F5F5 F5F5 F5FF 0000"
	$"00FF FF00 FFFF 00FF F5FF FFF5 F5FF 0000 00FF F5FF 0000 FFF5"
	$"F5F5 F5F5 F5FF 0000 00FF F5F5 FFFF F5F5 F5F5 F5F5 F5FF 0000"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics8' (131) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FF00 0000 00FF F5F5 F5F5 D8D8"
	$"F5F5 F500 FF00 0000 00FF F5F5 F5D8 D8D8 D8F5 F5F5 FFFF FF00"
	$"00FF F5F5 F5D8 D8D8 D8F5 F5F5 FFF9 FF00 00FF F5F5 F5F5 D8D8"
	$"F5F5 F5F5 FFF9 FF00 00FF F5F5 F5F5 FBFB F5F5 F5F5 FFF9 FF00"
	$"00FF F5F5 F5FB 0505 FBF5 F5F5 FFF9 FF00 00FF F5F5 F5FB 0505"
	$"FBF5 F5F5 FFF9 FF00 00FF F5F5 F5F5 FBFB F5F5 F5F5 FFF9 FF00"
	$"00FF F5F5 F5F5 E3E3 F5F5 F5F5 FFF9 FF00 00FF F5F5 F5E3 E3E3"
	$"E3FF FFFF FFF9 FF00 00FF F5F5 F5E3 E3E3 E3FF 2BFF F9F9 FF00"
	$"00FF F5F5 F5F5 E3E3 F5FF FFF9 F9F5 FF00 00FF FFFF FFFF FFFF"
	$"FFFF F9F9 F5F5 FF00 0000 00FF F9F9 F9F9 F9F9 F9F5 F5F5 FF00"
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FF"
};

resource 'ics#' (129) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0100 0280 0540 0BA0 1110 2008 4164 8392 414E 26F6 1106"
		$"0BFE 0546 0280 01",
		/* [2] */
		$"0000 0100 0380 07C0 0FE0 1FF0 3FF8 7FFC FFFE 7FFE 3FFE 1FFE"
		$"0FFE 07C6 0380 01"
	}
};

resource 'ics#' (128) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FE0 4030 4328 47BC 4784 4304 4304 4784 4784 4304 4304 4784"
		$"4784 4304 4004 7FFC",
		/* [2] */
		$"7FE0 7FF0 7FF8 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC"
		$"7FFC 7FFC 7FFC 7FFC"
	}
};

resource 'ics#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FF0 5F38 50AC 567C 5044 5644 5044 5644 5FC4 4C04 5204 6D04"
		$"6D64 5204 4C04 7FFC",
		/* [2] */
		$"7FF0 7FF8 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC"
		$"7FFC 7FFC 7FFC 7FFC"
	}
};

resource 'ics#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FF8 4308 478E 478A 430A 430A 478A 478A 430A 430A 47FA 47D2"
		$"4362 7FC2 1002 1FFE",
		/* [2] */
		$"7FFC 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE"
		$"7FFE 7FFE 7FFE 3FFE"
	}
};

resource 'ics4' (129) {
	$"0000 0000 0000 0000 0000 000F 0000 0000 0000 00F0 F000 0000"
	$"0000 0F03 0F00 0000 0000 F033 30F0 0000 000F 0C03 0C0F 0000"
	$"00F0 C0C0 C0C0 F000 0F0C 0C01 0FFC 0F00 F0C0 C011 FCCF C0F0"
	$"0F0C 0C0F CFCC FFF0 00F0 CFFC FFFF CFF0 000F 0C0F CCCC CFF0"
	$"0000 F088 FFFF FFF0 0000 0F08 0F00 0FF0 0000 00F0 F000 0000"
	$"0000 000F"
};

resource 'ics4' (128) {
	$"0FFF FFFF FFF0 0000 0F0C 0C0C 0CFF 0000 0FC0 C033 C0FC F000"
	$"0F0C 0333 3CFF FF00 0FC0 C333 30C0 CF00 0F0C 0C33 0C0C 0F00"
	$"0FC0 C0EE C0C0 CF00 0F0C 0E11 EC0C 0F00 0FC0 CE11 E0C0 CF00"
	$"0F0C 0CEE 0C0C 0F00 0FC0 C088 C0C0 CF00 0F0C 0888 8C0C 0F00"
	$"0FC0 C888 80C0 CF00 0F0C 0C88 0C0C 0F00 0FC0 C0C0 C0C0 CF00"
	$"0FFF FFFF FFFF FF"
};

resource 'ics4' (130) {
	$"0FFF FFFF FFFF 0000 0F0F FFFF 0CFF F000 0FCF C0C0 F0FC FF00"
	$"0F0F 033C 0FFF FF00 0FCF C0C0 CFC0 CF00 0F0F 011C 0F0C 0F00"
	$"0FCF C0C0 CFC0 CF00 0F0F 088C 0F0C 0F00 0FCF FFFF FFC0 CF00"
	$"0F0C FF0C 0C0C 0F00 0FCF 00F0 C0C0 CF00 0FF0 FF0F 0C0C 0F00"
	$"0FF0 FF0F CFF0 CF00 0F0F 00FC 0C0C 0F00 0FC0 FFC0 C0C0 CF00"
	$"0FFF FFFF FFFF FF"
};

resource 'ics4' (131) {
	$"0FFF FFFF FFFF F000 0FC0 C033 C0C0 F000 0F0C 0333 3C0C FFF0"
	$"0FC0 C333 30C0 FDF0 0F0C 0C33 0C0C FDF0 0FC0 C0EE C0C0 FDF0"
	$"0F0C 0E11 EC0C FDF0 0FC0 CE11 E0C0 FDF0 0F0C 0CEE 0C0C FDF0"
	$"0FC0 C088 C0C0 FDF0 0F0C 0888 8FFF FDF0 0FC0 C888 8FCF DDF0"
	$"0F0C 0C88 0FFD D0F0 0FFF FFFF FFDD 00F0 000F DDDD DDD0 00F0"
	$"000F FFFF FFFF FFF0"
};

resource 'BNDL' (128) {
	kOurCreatorType,
	0,
	{	/* array TypeArray: 2 elements */
		/* [1] */
		'FREF',
		{	/* array IDArray: 4 elements */
			/* [1] */
			0, 128,
			/* [2] */
			1, 129,
			/* [3] */
			2, 130,
			/* [4] */
			3, 131
		},
		/* [2] */
		'ICN#',
		{	/* array IDArray: 4 elements */
			/* [1] */
			0, 128,
			/* [2] */
			1, 129,
			/* [3] */
			2, 130,
			/* [4] */
			3, 131
		}
	}
};

resource 'FREF' (128) {
	kOurCreatorType,
	0,
	""
};

resource 'FREF' (129) {
	'APPL',
	1,
	""
};

resource 'FREF' (130) {
	'Pref',
	2,
	""
};

resource 'FREF' (131) {
	'sSp1',
	3,
	""
};

/******************************************************************************
*
* Our version resources tell people who use "Get Info" what version this is,
* and who made it.
*
******************************************************************************/

resource 'vers' (1) {
	0x3,
	0x0,
	beta,
	10,
	verUS,
	"3.0b10",
	"3.0b10 (first Pascal release)"
};

resource 'vers' (2) {
	0x3,
	0x0,
	beta,
	10,
	verUS,
	"3.0b10",
#ifdef PascalVersion
	"Pascal Sample 3.0"
#endif
#ifdef CVersion
	"C Sample 3.0"
#endif
};

/******************************************************************************
*
* This 'STR#' resource has the balloon help strings for the "Modify Circle"
* dialog.
*
******************************************************************************/

resource 'STR#' (circleDialogID,
#ifdef qDebug
				"Modify dialog help balloon strings",
#endif
				purgeable) {
	{	/* array StringArray: 24 elements */
		/* [1] */
		"Click here to make the circle in the document appear as it does in this dialog box.",
		/* [2] */
		"Click here to cancel all changes and leave the circle in the document window unchanged.",
		/* [3] */
		"Click here to see a menu listing all font choices available for the text in the circle.",
		/* [4] */
		"Type a value for the point size of the text inside the circle. You can only use digits, and the maximum size is 99 points.",
		/* [5] */
		"Click here to see a menu of common text sizes for the text in the circle, including whatever value is in the type-in field to the left.",
		/* [6] */
		"To make the text in the circle bolder, click this box.",
		/* [7] */
		"To make the text in the circle less bold, click this box.",
		/* [8] */
		"To make the text in the circle italicized, click this box.",
		/* [9] */
		"To make the text in the circle not italicized, click this box.",
		/* [10] */
		"To make the text in the circle underlined, click this box.",
		/* [11] */
		"To remove the underline beneath the text in the circle, click this box.",
		/* [12] */
		"To make the text in the circle appear outlined, click this box.",
		/* [13] */
		"To remove the outline appearance of the text in the circle, click this box.",
		/* [14] */
		"To make the text in the circle appear with a drop shadow, click this box.",
		/* [15] */
		"To remove the drop shadow on the text in the circle, click this box.",
		/* [16] */
		"To make the text in the circle narrower, click this box.",
		/* [17] */
		"To make the text in the circle less narrow, click this box.",
		/* [18] */
		"To make the text in the circle wider, click this box.",
		/* [19] */
		"To make the text in the circle less wide, click this box.",
		/* [20] */
		"To make the text in the circle appear without any extra styles, click this box.",
		/* [21] */
		"This box is checked because you have chosen no styles to apply to the text in the circle.  To apply a style, click one of the other checkboxes.",
		/* [22] */
		"Type text to appear in the circle here.",
		/* [23] */
		"Click this button to choose a new color for the circle using the Macintosh Color Picker.",
		/* [24] */
		"If you click the OK button, the circle in the document window will appear like this circle."
	}
};

/******************************************************************************
*
* These are the font names for default circles (up to ten of them).  It's
* always better to store fonts by name than by number since font ID numbers
* can vary from system to system.
*
******************************************************************************/

resource 'STR#' (rDefaultFonts,
#ifdef qDebug
				"Default font names",
#endif
				purgeable) {
	{	/* array StringArray: 10 elements */
		/* [1] */
		"Chicago",
		/* [2] */
		"Chicago",
		/* [3] */
		"Chicago",
		/* [4] */
		"Chicago",
		/* [5] */
		"Chicago",
		/* [6] */
		"Chicago",
		/* [7] */
		"Chicago",
		/* [8] */
		"Chicago",
		/* [9] */
		"Chicago",
		/* [10] */
		"Chicago"
	}
};

/******************************************************************************
*
* This 'STR#' resource contains the default text strings for circles.  The
* first three have traffic light-type values, and the rest are boring.
*
******************************************************************************/

resource 'STR#' (rDefaultStrings,
#ifdef qDebug
				"Default texts",
#endif
				purgeable) {
	{	/* array StringArray: 10 elements */
		/* [1] */
		"Stop",
		/* [2] */
		"Caution",
		/* [3] */
		"Go",
		/* [4] */
		"Circle #4",
		/* [5] */
		"Circle #5",
		/* [6] */
		"Circle #6",
		/* [7] */
		"Circle #7",
		/* [8] */
		"Circle #8",
		/* [9] */
		"Circle #9",
		/* [10] */
		"Circle #10"
	}
};

/******************************************************************************
*
* Macintosh Human Interface Guidelines says that the first untitled window
* should be named "untitled", the next one "untitled 2", etc.  The problem
* is the space character -- you can't append it to "untitled" easily without
* hard-coding it, and that's also internationally unfriendly.  Sample handles
* this with this 'STR#' resource -- the second string is the title of the first
* untitled window, and the first string is prepended to the results of
* NumToString to generate "untitled 3", "untitled 4", etc.
*
******************************************************************************/

resource 'STR#' (rUntitledStrings,
#ifdef qDebug
				"Untitled strings",
#endif
				purgeable) {
	{	/* array StringArray: 2 elements */
		/* [1] */
		"untitled ",
		/* [2] */
		"untitled"
	}
};

/******************************************************************************
*
* This 'STR#' resource has various miscellaneous strings.
*
******************************************************************************/

resource 'STR#' (rMiscStrings,
#ifdef qDebug
				"Miscellaneous Strings",
#endif
				purgeable) {
	{	/* array StringArray: 2 elements */
		/* [1] */
		"Save current document as:",
		/* [2] */
		"Select a color for this circle."
	}
};


/******************************************************************************
*
* This 'STR#' resource has lots of balloon help strings, mostly for our menu
* items.  These were generated by BalloonWriter.
*
******************************************************************************/

resource 'STR#' (5000, 
#ifdef qDebug
				"Balloon Help String 1", 
#endif
				purgeable) {
	{	/* array StringArray: 44 elements */
		/* [1] */
		"Circle menu\n\nUse this menu to operate on circles in document windows.",
		/* [2] */
		"Circle menu\n\nUse this menu to operate on circles in document windows.\n\nNot available because no document windows are available.",
		/* [3] */
		"Circle menu\n\nUse this menu to operate on circles in document windows.\n\nNot available because an alert box or modal dialog box is on your screen.",
		/* [4] */
		"Circle menu\n\nUse the items in this menu to operate on circles in document windows.\n\nNot available because an alert box or modal dialog box is on your screen.",
		/* [5] */
		"Adds a new default circle.",
		/* [6] */
		"Adds a new default circle. Not available because the current document already contains the maximum number of circles as specified in the preferences, or because no documents are open.",
		/* [7] */
		"Lets you modify the text, text size, text style and font of the currently selected circle, as well as its color if your Macintosh supports color.",
		/* [8] */
		"Lets you modify the text, text size, text style and font of the currently selected circle, as well as its color if your Macintosh supports color. Not available because there are no documents open.",
		/* [9] */
		"Removes the currently selected circle.",
		/* [10] */
		"Removes the currently selected circle from the current document. Not available because no documents are open, or because theres only one circle in the current document.",
		/* [11] */
		"Edit menu\n\nUse this menu to perform operations involving editing.",
		/* [12] */
		"Edit menu\n\nUse this menu to perform operations involving editing. Not available because theres nothing to edit right now.",
		/* [13] */
		"Cancels the last editing command.",
		/* [14] */
		"Cancels the last editing command.  Not available because the last command cant be canceled at this point.",
		/* [15] */
		"Cuts the selected text or graphics. The material you cut is removed and placed temporarily into a storage area called the Clipboard.",
		/* [16] */
		"Cuts the selected text or graphics. The material you cut is removed and placed temporarily into a storage area called the Clipboard. Not available because no text or graphics are selected.",
		/* [17] */
		"Copies the selected text or graphics into a temporary storage area called the Clipboard.",
		/* [18] */
		"Copies the selected text or graphics into a temporary storage area called the Clipboard. Not available because no text or graphics are selected.",
		/* [19] */
		"Inserts the contents of the Clipboard at the current insertion point.",
		/* [20] */
		"Inserts the contents of the Clipboard at the current insertion point. Not available because the Clipboard is empty.",
		/* [21] */
		"Removes the currently selected text or graphics without placing them on the clipboard.",
		/* [22] */
		"Removes the currently selected text or graphics without placing it on the clipboard. Not available because no text or graphics are selected.",
		/* [23] */
		"File Menu\n\nUse this menu to perform operations with files, windows and printers.",
		/* [24] */
		"File Menu\n\nUse this menu to perform operations with files, windows and printers.\n\nNot available because a modal dialog or alert is on the screen.",
		/* [25] */
		"This sample application from Apples Developer Support Center doesnt do much, but it does demonstrate several useful programming techniques.",
		/* [26] */
		"File Menu\n\nUse the items in this menu to perform operations with files, windows and printers.\n\nNot available because a modal dialog or alert is on the screen.",
		/* [27] */
		"Opens a new document window.",
		/* [28] */
		"Opens the document you choose.",
		/* [29] */
		"Closes the frontmost window, after asking you if you want to save any changes you made.",
		/* [30] */
		"Closes the frontmost window.  Not available because there are no windows open.",
		/* [31] */
		"Saves the frontmost window to a document on disk, prompting you for a document name if you havent already chosen one.",
		/* [32] */
		"Saves the frontmost window to a document on disk, prompting you for a document name if you havent already chosen one. Not available because there are no documents open, or because the frontmost window doesnt need to be saved.",
		/* [33] */
		"Saves the frontmost window into a document with a name you choose.",
		/* [34] */
		"Saves the frontmost window into a document with a name you choose.  Not available because there are no documents open.",
		/* [35] */
		"Restores the current document to the contents it had when you last saved it.",
		/* [36] */
		"Restores the current document to the contents it had when you last saved it. Not available because the document hasn't been saved, or because no documents are open.",
		/* [37] */
		"Displays a dialog that lets you set paper size, orientation and other printing options for the current document.",
		/* [38] */
		"Displays a dialog that lets you set paper size, orientation and other printing options for the current document.  Not available because there are no documents open.",
		/* [39] */
		"Prints the current document.",
		/* [40] */
		"Prints the current document.  Not available because no documents are open.",
		/* [41] */
		"Quits Sample.  If you haven't saved changes to any open documents, you'll be asked if you wish to do before quitting.",
		/* [42] */
		"Gives information about this application.",
		/* [43] */
		"This is the active light in this document.  You can modify its appearance by double-clicking it or selecting Modify Circle... from the Circle menu.",
		/* [44] */
		"This is an inactive light.  To activate this light, click in it."
	}
};

/******************************************************************************
*
* This 'hdlg' resource contains balloon help for the Modify Circle dialog.
* It mostly references the other 'STR#' resources already defined.  Like
* the Finder resources, we recommend using resource editors or other visual
* tools to help construct these things.  We did; this was created with the
* same resource editor that helped create the dialog.  Since it's not
* referenced by the code directly, there aren't any symbolic constants for
* the stuff here and it's mostly presented without comment.
*
******************************************************************************/

resource 'hdlg' (circleDialogID, purgeable) {
	2,
	0,
	0,
	0,
	0,
	HMSkipItem {

	},
	{	/* array HDialogArray: 22 elements */
		/* [1] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			1,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [2] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			2,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [3] */
		HMSkipItem {

		},
		/* [4] */
		HMSkipItem {

		},
		/* [5] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			3,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [6] */
		HMSkipItem {

		},
		/* [7] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			4,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [8] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			5,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [9] */
		HMSkipItem {

		},
		/* [10] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			6,
			0,
			0,
			130,
			7,
			0,
			0
		},
		/* [11] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			8,
			0,
			0,
			130,
			9,
			0,
			0
		},
		/* [12] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			10,
			0,
			0,
			130,
			11,
			0,
			0
		},
		/* [13] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			12,
			0,
			0,
			130,
			13,
			0,
			0
		},
		/* [14] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			14,
			0,
			0,
			130,
			15,
			0,
			0
		},
		/* [15] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			16,
			0,
			0,
			130,
			17,
			0,
			0
		},
		/* [16] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			18,
			0,
			0,
			130,
			19,
			0,
			0
		},
		/* [17] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			20,
			0,
			0,
			130,
			21,
			0,
			0
		},
		/* [18] */
		HMSkipItem {

		},
		/* [19] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			22,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [20] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			130,
			23,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [21] */
		HMStringResItem {
			{0, 0},
			{0, 0, 0, 0},
			0,
			0,
			130,
			24,
			0,
			0,
			0,
			0
		},
		/* [22] */
		HMSkipItem {

		}
	}
};

/******************************************************************************
*
* This resource, with the predefined ID -5696, tells the Help Manager how
* to find a string to use for balloon help for our application icon when
* balloons are shown and the user points to the application icon in the
* Finder.  This one tells the Help Manager to use string #25 in 'STR#' resource
* #5000.
*
******************************************************************************/

resource 'hfdr' (-5696, purgeable) {
	2,
	0,
	0,
	0,
	{	/* array HFdrArray: 1 elements */
		/* [1] */
		HMStringResItem {
			5000,
			25
		}
	}
};

/******************************************************************************
*
* These are the help menu resources to provide balloon help for our menus.
* The help strings are mostly in 'STR#' resource #5000, and these resources
* extract help strings from there.
*
******************************************************************************/

resource 'hmnu' (mEdit, "Edit", purgeable) {
	2,
	0,
	0,
	0,
	HMSkipItem {

	},
	{	/* array HMenuArray: 7 elements */
		/* [1] */
		HMStringResItem {
			5000,
			11,
			5000,
			12,
			0,
			0,
			0,
			0
		},
		/* [2] */
		HMStringResItem {
			5000,
			13,
			5000,
			14,
			0,
			0,
			0,
			0
		},
		/* [3] */
		HMSkipItem {

		},
		/* [4] */
		HMStringResItem {
			5000,
			15,
			5000,
			16,
			0,
			0,
			0,
			0
		},
		/* [5] */
		HMStringResItem {
			5000,
			17,
			5000,
			18,
			0,
			0,
			0,
			0
		},
		/* [6] */
		HMStringResItem {
			5000,
			19,
			5000,
			20,
			0,
			0,
			0,
			0
		},
		/* [7] */
		HMStringResItem {
			5000,
			21,
			5000,
			22,
			0,
			0,
			0,
			0
		}
	}
};

resource 'hmnu' (mCircle, "Circle", purgeable) {
	2,
	0,
	0,
	0,
	HMSkipItem {

	},
	{	/* array HMenuArray: 4 elements */
		/* [1] */
		HMStringResItem {
			5000,
			1,
			5000,
			2,
			5000,
			3,
			5000,
			4
		},
		/* [2] */
		HMStringResItem {
			5000,
			5,
			5000,
			6,
			0,
			0,
			0,
			0
		},
		/* [3] */
		HMStringResItem {
			5000,
			7,
			5000,
			8,
			0,
			0,
			0,
			0
		},
		/* [4] */
		HMStringResItem {
			5000,
			9,
			5000,
			10,
			0,
			0,
			0,
			0
		}
	}
};

resource 'hmnu' (mApple, "Apple menu", purgeable) {
	2,
	0,
	0,
	0,
	HMSkipItem {

	},
	{	/* array HMenuArray: 2 elements */
		/* [1] */
		HMSkipItem {

		}		,
		/* [2] */
		HMStringResItem {
			5000,
			42,
			0,
			0,
			0,
			0,
			0,
			0
		}
	}
};

resource 'hmnu' (mFile, "File", purgeable) {
	2,
	0,
	0,
	0,
	HMSkipItem {

	},
	{	/* array HMenuArray: 13 elements */
		/* [1] */
		HMStringResItem {
			5000,
			23,
			0,
			0,
			5000,
			24,
			5000,
			26
		},
		/* [2] */
		HMStringResItem {
			5000,
			27,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [3] */
		HMStringResItem {
			5000,
			28,
			0,
			0,
			0,
			0,
			0,
			0
		},
		/* [4] */
		HMSkipItem {

		},
		/* [5] */
		HMStringResItem {
			5000,
			29,
			5000,
			30,
			0,
			0,
			0,
			0
		},
		/* [6] */
		HMStringResItem {
			5000,
			31,
			5000,
			32,
			0,
			0,
			0,
			0
		},
		/* [7] */
		HMStringResItem {
			5000,
			33,
			5000,
			34,
			0,
			0,
			0,
			0
		},
		/* [8] */
		HMStringResItem {
			5000,
			35,
			5000,
			36,
			0,
			0,
			0,
			0
		},
		/* [9] */
		HMSkipItem {

		},
		/* [10] */
		HMStringResItem {
			5000,
			37,
			5000,
			38,
			0,
			0,
			0,
			0
		},
		/* [11] */
		HMStringResItem {
			5000,
			39,
			5000,
			40,
			0,
			0,
			0,
			0
		},
		/* [12] */
		HMSkipItem {

		},
		/* [13] */
		HMStringResItem {
			5000,
			41,
			0,
			0,
			0,
			0,
			0,
			0
		}
	}
};

/******************************************************************************
*
* These 'rgb ' resources (for which there's no ResEdit template) contain
* default colors for four of the ten maximum circles.  The first three
* use the customary US traffic light colors (red, yellow and green); the
* fourth one is blue and others are set to a hard-coded default by the
* TrafficLights code.
*
******************************************************************************/

data 'rgb ' (1000, 
#ifdef qDebug
			"Default color", 
#endif
			purgeable) {
	$"0000 0000 FFFF"                                                             /* .... */
};

data 'rgb ' (1001, purgeable) {
	$"FFFF 0000 0000"                                                             /* .... */
};

data 'rgb ' (1002, purgeable) {
	$"FFFF FFFF 0000"                                                             /* .. */
};

data 'rgb ' (1003, purgeable) {
	$"0000 9C40 0000"                                                             /* ..@.. */
};

data 'rgb ' (1004, purgeable) {
	$"B86B B86B B86B"                                                             /* kkk */
};

/******************************************************************************
*
* These integers in 'DfSz' resources are the default text sizes for the
* circles.  The program expects to find these resources to tell it what size
* text to use for new circles.  The first one controls the first circle,
* etc.
*
******************************************************************************/

data 'DfSz' (1000, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1001, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1002, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1003, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1004, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1005, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1006, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1007, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1008, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

data 'DfSz' (1009, 
#ifdef qDebug
			"Default sizes", 
#endif
			purgeable) {
	$"000C"                                                                       /* .. */
};

/******************************************************************************
*
* The 'DLOG' resources define the top-level dialog parameters, just like
* the 'ALRT' resources do for alerts.  There's not much interesting here.
*
******************************************************************************/

resource 'DLOG' (circleDialogID,
#ifdef qDebug
				"Circle options",
#endif
				purgeable) {
	{56, 76, 283, 436},
	dBoxProc,
	invisible,
	noGoAway,
	0x0,
	circleDialogID,
	"",
	centerParentWindow
};

resource 'DLOG' (prefsID,
#ifdef qDebug
				"Preferences",
#endif
				purgeable) {
	{48, 81, 252, 441},
	dBoxProc,
	visible,
	goAway,
	0x0,
	prefsID,
	"",
	alertPositionMainScreen
};

/******************************************************************************
*
* The owner resource is part of the Finder canon.
*
******************************************************************************/

type kOurCreatorType as 'STR ';

resource kOurCreatorType (0

#ifdef qDebug
				, "Owner resource"
#endif
				) {
	"Copyright 1993 Apple Computer, Inc."
};

/******************************************************************************
*
* Wow, something interesting -- the SIZE resource!  This tells the Process
* Manager (or MultiFinder, under System 6) what kind of citizen we are in the
* multitasking world.
*
******************************************************************************/

resource 'SIZE' (-1) {
	reserved,
	acceptSuspendResumeEvents,		/* we process these in our event loop */
	reserved,
	canBackground,					/* we handle backgrounding just fine */
	multiFinderAware,				/* we know to activate/deactivate    */
	backgroundAndForeground,		/* not a background-only application */
	dontGetFrontClicks,				/* we don't want to process mouse-down
									   events when they also bring us to the
									   front (like the Finder does)		 */
	ignoreChildDiedEvents,			/* These are for debuggers, not us   */
	is32BitCompatible,				/* We're completely 32-bit clean 	 */
	isHighLevelEventAware,			/* We handle Apple events correctly  */
	onlyLocalHLEvents,				/* By default, the "accept remote HL
									   events" checkbox in the "Sharing..."
									   window for this application is not
									   checked.  Users can change this.	 */
	isStationeryAware,				/* We know how to handle stationery,
									   so the Finder doesn't have to make
									   a copy of stationery files for us */
	dontUseTextEditServices,		/* We don't use the TextEdit Services
									   provided for international text entry */
	reserved,
	reserved,
	reserved,
	kPrefSize*1024,					/* Our preferred partition size		 */
	kMinSize*1024					/* The minimum we must have to run	 */
};

/******************************************************************************
*
* This small icon resource contains the down-pointing triangle that we draw
* _inside_ pop-up user items.  This is different from the 'PICT' resource
* that is not only the down-pointing triangle, but a rectangle with drop
* shadow surrounding it.
*
******************************************************************************/

resource 'SICN' (rPopDownArrowID, purgeable) {
	{	/* array: 1 elements */
		/* [1] */
		$"0000 0000 0000 0000 0000 0000 3FF8 1FF0 0FE0 07C0 0380 01"
	}
};

/******************************************************************************
*
* This is the window resource for all our document windows.  Our code resizes
* this window and replaces the title before it shows, so the rectangle and
* title are pretty much irrelevant.
*
******************************************************************************/

resource 'WIND' (rWindow, purgeable, preload) {
	{40, 16, 340, 116},
	noGrowDocProc,
	invisible,
	goAway,
	0x0,
	"",
	staggerParentWindow
};

